@@ -1,9 +1,10 @@
 #!/usr/bin/python2.5
 import sys
-import os
+import os 
 import Image, ImageEnhance
 import ImageDraw
 import ImageFont
+from PyQt4.QtMaemo5 import QMaemo5InformationBox
 from PyQt4 import QtGui,QtCore
 from PyQt4.QtGui import QIcon
 from shortcutmkr import *
@@ -11,26 +12,7 @@ contact = ('')
 num = ('')
 ico = ('')
 new = ('')
-def watermark(im, mark, position, opacity=1):
-    """Adds a watermark to an image."""
- 
-    layer = Image.new('RGBA', im.size, (0,0,0,0))
-    if position == 'tile':
-        for y in range(0, im.size[1], mark.size[1]):
-            for x in range(0, im.size[0], mark.size[0]):
-                layer.paste(mark, (x, y))
-    elif position == 'scale':
-        # scale, but preserve the aspect ratio
-        ratio = min(
-            float(im.size[0]) / mark.size[0], float(im.size[1]) / mark.size[1])
-        w = int(mark.size[0] * ratio)
-        h = int(mark.size[1] * ratio)
-        mark = mark.resize((w, h))
-        layer.paste(mark, ((im.size[0] - w) / 2, (im.size[1] - h) / 2))
-    else:
-        layer.paste(mark, position)
-    # composite the watermark with the layer
-    return Image.composite(layer, im, layer)
+
 
 class MyForm(QtGui.QMainWindow):
 	def __init__(self, parent=None):
@@ -78,7 +60,7 @@ class MyForm(QtGui.QMainWindow):
 		if self.ui.checkBox_6.isChecked():
 			self.ui.lineEdit_4.setText(self.ui.lineEdit.text()) 
 			self.ui.lineEdit_5.setText(self.ui.lineEdit_2.text())
-		
+                        
 #endtabchange	
 
 
@@ -111,6 +93,7 @@ Icon='''+sm+'''''',
 			fsock.close()
 			contact = ('')
 			num = ('')	
+			QMaemo5InformationBox.information(self,"SMS Shortcut Created")
 
 		if self.ui.tabWidget.currentIndex() is  1:
 			if self.ui.lineEdit_3.isModified():
@@ -139,7 +122,7 @@ Icon='''+sm+''''''
 			fsock3.close()
 			contact = ('')
 			num = ('')
-
+			QMaemo5InformationBox.information(self,"Call Shortcut Created")
 
 
 		if self.ui.tabWidget.currentIndex() is  2:
@@ -169,7 +152,7 @@ Icon='''+sm+''''''
 			fsock2.close()
 			contact = ('')
 			num = ('')
-
+			QMaemo5InformationBox.information(self,"Email Shortcut Created")
 
 		if self.ui.tabWidget.currentIndex() is  3:
 			if self.ui.lineEdit_3.isModified():
@@ -202,7 +185,7 @@ Icon='''+sm+''''''
 			fsock4.close()
 			contact = ('')
 			num = ('')
-
+			QMaemo5InformationBox.information(self,"Command Shortcut Created")
 
 
 
@@ -254,30 +237,33 @@ Icon='''+sm+''''''
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_3.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_4.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		if self.ui.checkBox_5.isChecked():
 			contact = self.ui.lineEdit_10.text()
 			os.remove('/usr/share/applications/hildon/cmd'+contact+'.desktop')
 			contact = ('')
 			num = ('')
 			self.ui.lineEdit_10.clear()
+			QMaemo5InformationBox.information(self,"Shortcut Deleted")
 		self.ui.checkBox_2.setChecked(False)
 		self.ui.checkBox_3.setChecked(False)
 		self.ui.checkBox_4.setChecked(False)
 		self.ui.checkBox_5.setChecked(False)
 
-
 	
 #end button actions
 
@@ -298,7 +284,7 @@ Icon='''+sm+''''''
 		self.ui.lineEdit_3.setText(filen)
 		self.ui.label_3.setPixmap(QtGui.QPixmap((filename)));
 		self.ui.lineEdit_3.setModified(True)
-		
+		QMaemo5InformationBox.information(self,"Icon Selected")
 
 	
 				
@@ -352,7 +338,7 @@ Icon='''+sm+''''''
 		self.ui.lineEdit_3.setText('/usr/share/icons/scm'+mytext+".png")
 		self.ui.label_3.setPixmap(QtGui.QPixmap(('/usr/share/icons/scm'+mytext+".png")));
 		self.ui.lineEdit_3.setModified(True)
-
+		QMaemo5InformationBox.information(self,"Icon Created")
 	
 
 
@@ -363,7 +349,7 @@ Icon='''+sm+''''''
 		self.ui.lineEdit_3.clear()
 		self.ui.label_3.clear()
 		self.ui.lineEdit_3.setModified(False)
-  	   
+		QMaemo5InformationBox.information(self,"Icon Deleted")
 if __name__ == "__main__":
 	app = QtGui.QApplication(sys.argv)
 	myapp = MyForm()
